__author__ = 'pav'
#-------------------------------------------------------------------------------------
#
#           HELPERS.CHECK MODULE:
#               > INITIAL DATASET OBJECT
#               > LOG FILES METHODS AND INITIAL STATS
#
#-------------------------------------------------------------------------------------
import os
import re
from geodata.core.image.processor import ImageMeta
from geodata.settings import ZOOM, DATA_LOGS, CreateLogDir


class DatasetDefault():
    """
        Check Initial Data set before procedure
    """

    def __init__(self, zpath, wpath, region):
        self.zpath = zpath
        self.wpath = wpath
        self.wide = {}
        self.tele = {}
        self.time = []
        self.gps = []
        CreateLogDir()
        self.region = os.path.join(
            DATA_LOGS, region
        )
        if not os.path.exists(self.region):
            os.makedirs(self.region)


    def CheckInit(self):
        self.time = []
        self.gps = []

    def ShowInfo(self, mode):
        if mode == 1:
            ch = self.wide
        else:
            ch = self.tele

        response = """
        ----- %s: %s photos Results ----------

          total files: %d
          unique gps: %d
          unique timestamp: %d
        """ % (os.path.split(self.region)[-1], ZOOM[mode], len(ch), len(set(self.gps)), len(set(self.time)))
        return response


    def WideCheck(self):
        self.CheckInit()
        output = os.path.join(
            self.region,
            "wide.txt"
        )
        wf = "{}#{}#{}#{}\n"
        data = [ photo for photo in os.listdir(self.wpath) if photo != "Thumbs.db"]
        socket = open(output, 'w')
        for photo in data:
            a, b, c = ImageMeta(os.path.join(self.wpath, photo))
            self.wide[photo] = {
                "lat": a,
                "lon": b,
                "ts": c
            }
            self.time.append(c)
            self.gps.append("%s %s" % (a, b))
            socket.write(wf.format(photo, a, b, c))
        socket.close()


    def TeleCheck(self):
        self.CheckInit()
        output = os.path.join(
            self.region,
            "tele.txt"
        )
        wf = "{}#{}#{}#{}\n"
        data = [ photo for photo in os.listdir(self.zpath) if photo != "Thumbs.db"]
        socket = open(output, 'w')
        for photo in data:
            a, b, c = ImageMeta(os.path.join(self.zpath, photo))
            self.tele[photo] = {
                "lat": a,
                "lon": b,
                "ts": c
            }
            self.time.append(c)
            self.gps.append("%s %s" % (a, b))
            socket.write(wf.format(photo, a, b, c))
        socket.close()




def UnitTest():


    inst = DatasetDefault(
        r'C:\\Users\\pav\\Desktop\\dbdata\\dataset-GEO\\Teles',
        r'C:\\Users\\pav\\Desktop\\dbdata\\dataset-GEO\\Wides',
        'Spetsopoula'
    )
    print DATA_LOGS
    print inst.region

    inst.WideCheck()
    print inst.ShowInfo(1)
    inst.TeleCheck()
    print inst.ShowInfo(2)


if __name__ == '__main__':
    UnitTest()

