__author__ = 'pav'
#-------------------------------------------------------------------------------------
#
#           HELPERS.SHORTCUTS MODULE:
#               > DATA TYPE HELP FUNCTIONS
#               > DATETIME HANDLE FUNCTIONS
#
#-------------------------------------------------------------------------------------
from datetime import datetime
from time import mktime
from operator import itemgetter
from geodata.settings import MINMAX
#-------------------------------------------------------------------------------------
#-------------- DATA STRUCTURES SORTING - FORMATING FUNCTIONALITY  --------------------

def KeySort(dset):
    """
        Returns a sorted list of a dictionary's keys  sorted by key
    """
    return sorted(dset, key=dset.get)

def ValueSort(dset):
    '''
        Returns a sorted list of a dictionary keys sorted by value
    '''
    return sorted(dset.items(), key=lambda x: x[1])

def OrderListByValue(obj, index):
    """
        Returns sorted list of lists by child list value - based on index
    """
    return sorted(obj, key=itemgetter(0,index))


def DictToListSorted(data):
    """
        Return a sorted list from a dictionary
    """
    resp = []
    for i in sorted(data.iterkeys()):
        resp.append([
            data[i]['img'],
            data[i]['xy'],
            i,
            data[i]['play'],
            data[i]['vid']
        ])
    return resp


def FindMaxMinIndex(data, index, opt):
    """
        Returns the index of the max value of list of lists
    """
    value = [ k[index] for k in data ]
    return [data.index(i) for i in data if i[index] == MINMAX[opt](value)].pop()

def UpdateListColumn(data, index, offset):
    """
        Add an offfset to a columns list of a list
    """
    for i in data: i[index] = int(i[index]) + offset
    return data

#--------------------------- END OF DATA STRUCTURES FUNCTIONALITY --------------------
#-------------------------------------------------------------------------------------


#------------------------- DATETIME CONVERSIONS AND FUNCTIONALITY --------------------
#-------------------------------------------------------------------------------------

def DateTimeAdd(sec):
    resp = str(int(sec) + 1)
    if len(resp) == 1:
        return "0" + resp
    else:
        return resp


def DateToUnix(strformat):
    """
        Transform Datetime format to UNIX epoch time
    """
    date, time = strformat.split()
    ts = [int(i) for i in date.split("-")] + [int(i) for i in time.split(":")]
    ts = datetime(ts[0], ts[1], ts[2], ts[3], ts[4], ts[5])
    return int(mktime(ts.timetuple()))

def UnixToDate(unixformat):
    """
        Transform Unix epoch time to Datetime format
    """
    return datetime.fromtimestamp(int(unixformat)).strftime('%Y-%m-%d %H:%M:%S')



def MinuteToSec(duration):
    h, m, sec = duration.split(":")
    return int(m)*60 + int(float(sec))

#---------------------------- END OF DATETIME FUNCTIONALITY -------------------------
#-------------------------------------------------------------------------------------



#----------------- FUNCTIONAL TEST UNIT FOR SHORTCUTS MODULE -------------------------
def Test():

    a = [
        ['_TIP0329.jpg', '37.2795866667', '23.2803516667', 1378806477, '7'],
        ['_TIP0330.jpg', '37.2794733333', '23.2800166667', 1378806478, '8'],
        ['_TIP0331.jpg', '37.27936', '23.2796816667', 1378806479, '9'],
        ['_TIP0332.jpg', '37.27086', '23.274605', 1378806522, '52'],
        ['_TIP0334.jpg', '37.27039', '23.274775', 1378806523, '53'],
        ['_TIP0335.jpg', '37.27039', '23.274775', 1378806524, '54'],
        ['_TIP0337.jpg', '37.2699066667', '23.27486', 1378806525, '55'],
        ['_TIP0338.jpg', '37.2699066667', '23.27486', 1378806526, '56'],
        ['_TIP0339.jpg', '37.2694166667', '23.2748633333', 1378806527, '57'],
        ['_TIP0340.jpg', '37.2661983333', '23.2737766667', 1378806541, '71'],
        ['_TIP0342.jpg', '37.26576', '23.2735', 1378806543, '73'],
        ['_TIP0343.jpg', '37.2655483333', '23.2733616667', 1378806544, '74'],
        ['_TIP0344.jpg', '37.2653366667', '23.2732216667', 1378806545, '75'],
        ['_TIP0346.jpg', '37.2636783333', '23.2901483333', 1378806634, '164'],
        ['_TIP0347.jpg', '37.264205', '23.2904333333', 1378806636, '166'],
        ['_TIP0348.jpg', '37.2653283333', '23.29063', 1378806640, '170'],
        ['_TIP0333.jpg', '37.2706283333', '23.2747', '1378806523', '53'],
        ['_TIP0336.jpg', '37.27015', '23.2748283333', '1378806525', '55'],
        ['_TIP0341.jpg', '37.2659766667', '23.2736383333', '1378806542', '72'],
        ['_TIP0345.jpg', '37.2651233333', '23.2730816667', '1378806546', '76']
    ]

    b =  OrderListByValue(a,3)
    for i in b:
        print i

if __name__ == '__main__':
    Test()