__author__ = 'pav'
#-------------------------------------------------------------------------------------
#
#           DIST.DATA_BACKEND.LOGS MODULE:
#               > ADVANCED DATA PROCEDURE TYPE HELP FUNCTIONS
#               > FEATURE EXTRACT AND CORRECTION
#
#
#       wdata - tdata list: [ img, lon, lat, timestamp, ttp, id, video_id, prev_id, next_id, wide_tele_flag ]
#
#       Usage:
#            object = DataEntry(
#                path/to/wide/photos/folder/,
#                path/to/tele/photos/folder/,
#                path/to/videos/folder/,
#                Region_name
#            )
#
#            object.DataBuilder()
#
#-------------------------------------------------------------------------------------
from geodata.core.helpers.check import DatasetDefault, DATA_LOGS, os, re
from geodata.core.helpers.shortcuts import DateTimeAdd, DateToUnix, OrderListByValue, UnixToDate
from geodata.core.helpers.db_position import GetLastPosition
from geodata.core.video.processors import GetDuration
from geodata.core.classifiers.generic import VideoTeleTag
from datetime import datetime

class DataEntry():
    """
        Initialize every new region dataset
        with log files and pre - procecced data entries
    """

    def __init__(self, wdir, tdir, videodir,region):
        self.region  = {
            "id": GetLastPosition("geoindex", "geotag", "iverson", "region")+1,
            "name":region,
            "description": """ This is some extra text to fill in later from django admin""",
            "date": datetime.now().isoformat()
        }
        self.video_path = videodir
        self.initialize = DatasetDefault(tdir, wdir, region)
        self.wfile = os.path.join(self.initialize.region, "wide.txt")
        self.tfile = os.path.join(self.initialize.region, "tele.txt")
        self.wdata = []
        self.tdata = []
        self.video_list = []
        self.wstart = 0
        self.tstart = 0

    def InitialBuilder(self):
        self.InitData()
        self.ReLoad()

    def InitData(self):
        self.initialize.WideCheck()
        a = self.initialize.ShowInfo(1)
        self.initialize.TeleCheck()
        b = self.initialize.ShowInfo(2)
        sock = open(os.path.join(self.initialize.region, "log.txt"), 'w')
        sock.write(a + "\n\n" + b)
        sock.close()
        print a
        print b


    def ReLoad(self):
        sock = open(self.wfile, 'r')
        for line in sock:
            img, lat, lon, timestamp = line.split("#")
            self.wdata.append([
                img, lat, lon, timestamp
            ])
        sock.close()
        sock = open(self.tfile, 'r')
        for line in sock:
            img, lat, lon, timestamp = line.split("#")
            self.tdata.append([
                img, lat, lon, timestamp
            ])
        sock.close()

    def Sanitize(self, video_offset=7):
        """
            Procedure of initial DATA
        """


        #-------- Ordering Time Trans, Correction --------
        self.tdata = OrderListByValue(self.tdata, 3)
        self.tdata = self.TimeTrans(self.tdata)
        self.tdata = self.TimeCorrection(self.tdata)
        self.tdata = OrderListByValue(self.tdata, 3)


        self.wdata = OrderListByValue(self.wdata, 3)
        self.wdata = self.TimeTrans(self.wdata)
        self.wdata = self.TimeCorrection(self.wdata)
        self.wdata = OrderListByValue(self.wdata, 3)


        #----- Video Correction -------------
        self.VideoChopper()

        #---------- Find Time to Play for each dataset ----------
        self.FindPlayTime(self.wdata, offset=0)
        self.FindPlayTime(self.tdata, offset=0)
        tmp = self.tdata
        self.tdata = VideoTeleTag(self.wdata, self.tdata, int(self.video_list[0][self.video_list[0].keys()[0]]["duration"]),4, tmp)



        #self.FindPlayTime(self.tdata, offset=video_offset)

        #----------- GPS Correction and logs ----------------
        self.tdata = self.WatchGPS(self.tdata)

        self.wdata = self.WatchGPS(self.wdata)

        self.GPSCheck(self.wdata)
        self.GPSCheck(self.tdata)


        #---------- OID's Marking ----------------
        start_point = GetLastPosition("geoindex", "geotag", "iverson", 'geoimage')

        self.tdata, new_start = self.UIDData(self.tdata, start_point=start_point)



        self.wdata, final_oid = self.UIDData(self.wdata, start_point=new_start-1)

        ##----- Video Correction -------------
        #self.VideoChopper()
        #
        one_video_area = self.video_list[0]
        k = one_video_area.keys()[0]

        for i in self.wdata:
            i.append(one_video_area[k]['oid'])

        for i in self.tdata:
            i.append(one_video_area[k]['oid'])


        #---------- Circle nav ----------------------
        self.CircleNav(self.tdata)
        self.CircleNav(self.wdata)

        #--- Return to Human Timestamp ------

        for i in self.wdata:
            i[3] = UnixToDate(i[3])

        for i in self.tdata:
            i[3] = UnixToDate(i[3])

        #------- Set flags for wide tele -------
        for i in self.wdata:
            i.append("true")
        for i in self.tdata:
            i.append("false")
        for i in self.wdata:
            print i

        for i in self.video_list:
            print i


    def VideoChopper(self):
        video_list = [os.path.join(self.video_path, vid) for vid in os.listdir(self.video_path)]
        last = GetLastPosition("geoindex", "geotag", "iverson", 'originvideo') + 1
        start = 0
        offset = 1
        for i in video_list:
            self.video_list.append({
                i: {"oid": last, "duration": GetDuration(i), "start":start}
            })
            last = last + 1
            start = start + GetDuration(i) + offset
            offset = 0
        print self.video_list

    def FindStartPoint(self):
        a = self.tdata[0][3]
        b = self.wdata[0][3]
        offset= 3*60*60
        c = int(a) - offset
        print a
        print b

        print a -  c


    def UIDData(self, data, start_point):
        oid = start_point + 1
        for i in data:
            i.append(oid)
            oid = oid + 1
        return data, oid

    def CircleNav(self, data):
        for i in data:
            i.append(data[data.index(i)-1][5])
            if data.index(i) == len(data) - 1:
                i.append(data[0][5])
            else:
                i.append(data[data.index(i)+1][5])


    def TimeTrans(self, data):
        """
            Changes The timestamp value to unix epch time
        """
        for i in data:
            i[3] = DateToUnix(i[3])
        return data


    def TimeCorrection(self, data):
        """
            Correct the timestamp in unix epoch format
        """
        count = ''
        for i in data:
            if i[3] == count:
                i[3] = str(int(i[3]+1))
            count = i[3]
        return data

    def FindPlayTime(self, data, offset=0):
        sec = int(data[0][3])
        for i in data:
            i.append(str(int(i[3]) - sec + offset))
        return data

    def WatchGPS(self, data):
        gps_all = [(i[1], i[2]) for i in data]
        gps_tmp = {(i[1], i[2]): data.index(i) for i in data}
        gps_unique = set(gps_all)

        for i in gps_unique:
            gps_all.remove(i)

        for i in gps_all:
            m = self.GPSCorrect(i)
            data[gps_tmp[i]][1], data[gps_tmp[i]][2] = m[0], m[1]

        return data

    def GPSCorrect(self, xy):
        offset = 0.00001
        lon, lat = xy[0], xy[1]
        lon = float(lon) +  float(offset)
        lat = float(lat) +  float(offset)
        return (str(lon), str(lat))

    def GPSCheck(self, data):
        tmp = [ (i[1], i[2]) for i in data]
        print "Unique GPS: %d" % len(tmp)

if __name__ == '__main__':
    inst = DataEntry(
        r'C:\\Users\\pav\\Desktop\\dbdata\\dataset-GEO\\trikeri\\Wide',
        r'C:\\Users\\pav\\Desktop\\dbdata\\dataset-GEO\\trikeri\\Tele',
        r'C:\\Users\\pav\\Desktop\\dbdata\\dataset-GEO\\trikeri\\video',
        'Trikeri'
    )
    inst.InitialBuilder()
    inst.Sanitize(video_offset=7)
