__author__ = 'pav'
#---------------------------------------------------------------------------------------------
#
#   QueryBuilder Class:
#       Fuctionality for building the QUERIES for our DB
#
#       Usage:
#           object = QueryBuilder()
#           object.setDB(name, usr, password)
#           object.ExecAll(region, photos, videos) or object.ExportAll(export_file, region, photos, videos)
#
#----------------------------------------------------------------------------------------------

from geodata.settings import QUERY, os, PREFIX, VIDEO_PREFIX
from geodata.core.db.pg_adaptor import DBHandler



class QueryBuilder():
    """
        Build the Standar QUERIES for the DB queries for the DB
    """

    def __init__(self):
        self.DB = None
        self.DB_MODE = {}

    def setDB(self, name, usr, password):
        self.DB = DBHandler(name, usr, password)
        self.DB_MODE["EXEC"] = self.DB.commit
        self.DB_MODE["SQL"] = self.DB.QueryCache

    def ExecAll(self, region, photos, videos):
        self.InsertRegion(region, "EXEC")
        self.InsertOriginVideo(videos, "EXEC")
        self.InsertGeoImages(photos, region, "EXEC")
        self.InsertGeoVideo(photos, region, "EXEC")

    def ExportAll(self, export_file, region, photos, videos):
        self.DB.sql_cache = []
        self.InsertRegion(region, "SQL")
        self.InsertOriginVideo(videos, "SQL")
        self.InsertGeoImages(photos, region, "SQL")
        self.InsertGeoVideo(photos, region, "SQL")

        sock = open(export_file, "w")
        for i in self.DB.sql_cache:
            sock.write(i)
        sock.close()

    def InsertRegion(self, region, mode):
        self.DB.connect()
        self.DB.query = QUERY["region"] % (region["id"],region["name"], region["date"],region["description"] )
        print self.DB.query
        self.DB.execute()
        self.DB_MODE[mode]()
        #self.DB.commit()
        print "\nDONE INSERTION of Region %s\n" % region["name"]

    def InsertOriginVideo(self, videos, mode):
        self.DB.connect()
        for i in videos:
            self.DB.query = QUERY["originvideo"] % (i[i.keys()[0]]["oid"], VIDEO_PREFIX + i.keys()[0])
            print self.DB.query
            self.DB.execute()
        self.DB_MODE[mode]()
        #self.DB.commit()
        print "\nDONE INSERTION of OriginVideos\n"

    def InsertGeoImages(self, photos, region, mode):
        self.DB.connect()
        for i in photos:
            self.DB.query = QUERY["geoimage"] % (
                i[5],
                PREFIX + region["name"] + "/" + i[0],
                i[3],
                "%s %s" % (i[2], i[1]),
                i[8],
                i[7],
                i[5],
                i[9],
                region["id"],
            )
            print self.DB.query
            self.DB.execute()
        self.DB_MODE[mode]()
        #self.DB.commit()
        print "\nDONE INSERTION of GeoImage Files for Region of %s\n" % region["name"]

    def InsertGeoVideo(self, photos, region, mode):
        self.DB.connect()
        for i in photos:
            self.DB.query = QUERY["geovideo"] % (
                i[5],
                i[6],
                i[5],
                i[4],
            )
            print self.DB.query
            self.DB.execute()
        self.DB_MODE[mode]()
        #self.DB.commit()
        print "\nDONE INSERTION of GeoVideo Records for Region of %s\n" % region["name"]
